@@ -206,7 +206,18 @@ class Jenkins(
         :param seed_jobs: List of seed job configuration for Jenkins resource. For more information about seed jobs, please take a look at { @link https://github.com/jenkinsci/job-dsl-plugin/wiki/Tutorial---Using-the-Jenkins-Job-DSL Jenkins Seed Jobs Documentation }. Default: - No seed jobs
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Jenkins.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+                disable_csrf_protection: typing.Optional[builtins.bool] = None,
+                metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
+                plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+                seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = JenkinsProps(
@@ -226,7 +237,9 @@ class Jenkins(
         :param base_plugins: List of base plugins.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Jenkins.add_base_plugins)
+            def stub(*base_plugins: "Plugin") -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument base_plugins", value=base_plugins, expected_type=typing.Tuple[type_hints["base_plugins"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addBasePlugins", [*base_plugins]))
 
@@ -237,7 +250,9 @@ class Jenkins(
         :param plugins: List of custom plugins.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Jenkins.add_plugins)
+            def stub(*plugins: "Plugin") -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument plugins", value=plugins, expected_type=typing.Tuple[type_hints["plugins"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addPlugins", [*plugins]))
 
@@ -248,7 +263,9 @@ class Jenkins(
         :param seed_jobs: List of seed jobs.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Jenkins.add_seed_jobs)
+            def stub(*seed_jobs: "SeedJob") -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument seed_jobs", value=seed_jobs, expected_type=typing.Tuple[type_hints["seed_jobs"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addSeedJobs", [*seed_jobs]))
 
@@ -285,7 +302,16 @@ class JenkinsProps:
         if isinstance(metadata, dict):
             metadata = cdk8s.ApiObjectMetadata(**metadata)
         if __debug__:
-            type_hints = typing.get_type_hints(JenkinsProps.__init__)
+            def stub(
+                *,
+                base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+                disable_csrf_protection: typing.Optional[builtins.bool] = None,
+                metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
+                plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+                seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument base_plugins", value=base_plugins, expected_type=type_hints["base_plugins"])
             check_type(argname="argument disable_csrf_protection", value=disable_csrf_protection, expected_type=type_hints["disable_csrf_protection"])
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
@@ -402,7 +428,14 @@ class Plugin:
         :param download_url: The url from where plugin has to be downloaded. Default: - Plugins are downloaded from Jenkins Update Centers.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Plugin.__init__)
+            def stub(
+                *,
+                name: builtins.str,
+                version: builtins.str,
+                download_url: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument version", value=version, expected_type=type_hints["version"])
             check_type(argname="argument download_url", value=download_url, expected_type=type_hints["download_url"])
@@ -480,7 +513,16 @@ class SeedJob:
         :param targets: The repository path where seed job definitions are present.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SeedJob.__init__)
+            def stub(
+                *,
+                description: builtins.str,
+                id: builtins.str,
+                repository_branch: builtins.str,
+                repository_url: builtins.str,
+                targets: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument repository_branch", value=repository_branch, expected_type=type_hints["repository_branch"])
